# aws-cost-report      
  
usage: cost-report \[-h\] \[-v\]  
  
command line tool which will return total cost for the current month's AWS usage.  
oraganizations with multiple accounts will see a list of accounts.  
  
usage:   
> $ cost-report  
  
expected output:  
> AWS Costs for Current Month - 8378\_ACCT\_ID (July): $2.18  
  
optional arguments:  
> -h, --help     show this help message and exit  
> -v, --version  show program's version number and exit  
